% compute the velocity profile fo the Falkner-Skan-Cooke boundary layer


%%%% parameters
Nfsc=100; %number of collocation points in the wall normal direction
Lfsc=20;%extent (in boundary layer thickness) of the computational domain in the wall normal direction
m=1.44232;%pressure gradient parameter

% variable for fsfun och cfun
global DMfsc;                
global Nfsc;
global Lfsc;
global BetaH;
global F;
global D1fsc
global D2fsc
global D3fsc

% Specify problem parameters
BetaH=2*m/(m+1);

% other way to give the pressure gradiant          
%wedgeangle = 0;           
%BetaH=wedgeangle/180.;

% differenciation matrices and scaling
[x,DMfsc]=chebdif(Nfsc,3);            

%diferentiation matrices for fsfun
D1fsc=DMfsc(3:Nfsc-1,2:Nfsc,1).*(-2/Lfsc);      
D2fsc=DMfsc(3:Nfsc-1,2:Nfsc,2).*(4/(Lfsc^2));
D3fsc=DMfsc(3:Nfsc-1,2:Nfsc,3).*(-8/(Lfsc^3));

%  Initial guess can be very important
f0=-(2*x(2:Nfsc)-2)*Lfsc/4-1.21.*(1-exp((x(2:Nfsc)-1)*Lfsc/2));
c0=-(2*x(2:Nfsc)-2)*Lfsc/4-1.21.*(1-exp((x(2:Nfsc)-1)*Lfsc/2));

%%%%  Compute Falkner-Skan Profile
f=fsolve('fsfun',f0,[0,1e-14,1e-14]);
F=f;
f=[0;f];
fprim=-2/Lfsc*(DMfsc(:,:,1)*f);% compute first derivative of f

%%%% Compute Cooke profile
g=fsolve('cfun',c0,[0,1e-10,1e-10]);
g=[0;g];

%%%% Rescale to deltastar scale
IW=INTweights(Nfsc,Lfsc);% compute integration weights
deltastar=sum(IW*(ones(Nfsc,1)-fprim));
yfsc=(1-x(1:Nfsc)).*(Lfsc/2)/deltastar;
Lfsc=Lfsc/deltastar;

%%%%  u, w and derivatives
d1=2/Lfsc;d2=d1*d1;%scalings 
u=fprim;
du=d1*DMfsc(:,:,1)*u;
ddu=d2*DMfsc(:,:,2)*u;
w=g;
dw=d1*DMfsc(:,:,1)*w;
ddw=d2*DMfsc(:,:,2)*w;

%%%% plot profiles
plot(u,yfsc,'-',du,yfsc,'-',ddu,yfsc,'-',w,yfsc,'--',dw,yfsc,'--',ddw,yfsc,'--');
legend('u','du','ddu','w','dw','ddw');